@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: cryptohash-conduit
 version: 0.1.1
-id: cryptohash-conduit-0.1.1-efae13840ebbb4413a12b1a104e96ba5
-key: crypt_52ZkbDxlXsTBbU1iKYRIkp
+id: cryptohash-conduit-0.1.1-e4bade99c5dbc09eaccf1f4fc13e0864
+key: crypt_0D42bvzqonC7duxZ9avsAD
 license: BSD3
 copyright: Vincent Hanquez <vincent@snarc.org>
 maintainer: vincent@snarc.org
@@ -22,14 +22,14 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/cryptohash-conduit-0.1.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/cryptohash-conduit-0.1.1
-hs-libraries: HScryptohash-conduit-0.1.1-52ZkbDxlXsTBbU1iKYRIkp
+hs-libraries: HScryptohash-conduit-0.1.1-0D42bvzqonC7duxZ9avsAD
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    conduit-1.2.6.1-99a58e37479a2070047844a872c4445f
-    conduit-extra-1.1.9.2-1bef4166ec3f53ae2e6d2e9011cd9cbe
+    conduit-1.2.6.1-0dc23cc567e1e45fd451d3d7a1cbf2ca
+    conduit-extra-1.1.9.2-79e9518024a2df5c3adcf7d7df9fbea5
     cryptohash-0.11.6-e28406db011dea16e99b7bc1708b91dc
-    resourcet-1.1.7-7e93b08fc7a9dc3281fd76904261e146
+    resourcet-1.1.7.1-53b70bd9a277fdc9d256cfbf9605d278
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
 haddock-interfaces: /usr/share/doc/haskell-cryptohash-conduit/html/cryptohash-conduit.haddock
 haddock-html: /usr/share/doc/haskell-cryptohash-conduit/html
